@@ -273,7 +273,7 @@ bool parse_limit(rlim_t *lim, const char *arg) {
  *   :hard
  *   +both   (this is unique to xchpst)
  */
-bool parse_limits(struct limit *limit, const char *arg) {
+bool parse_limits(struct limit *limit, char *arg) {
   char *sep;
   bool both = *arg == '+';
 
