@@ -4,6 +4,8 @@
 #ifndef _XCHPST_H
 #define _XCHPST_H
 
+#include <stdbool.h>
+
 #define STRINGIFY(x) _STRINGIFY(x)
 #define _STRINGIFY(x) #x
 
@@ -30,9 +32,5 @@ struct runtime {
 };
 
 extern struct runtime runtime;
-extern char *run_dir;
-
-extern int ensure_dir(int dirfd, const char *path, int *fd, mode_t mode);
-extern int get_run_dir(void);
 
 #endif
